@@ -13,7 +13,7 @@ PACKAGE = ROOT / "jsonschema_specifications"
 nox.options.sessions = []
 
 
-def session(default=True, **kwargs):
+def session(default=True, **kwargs):  # noqa: D103
     def _session(fn):
         if default:
             nox.options.sessions.append(kwargs.get("name", fn.__name__))
@@ -24,6 +24,9 @@ def session(default=True, **kwargs):
 
 @session(python=["3.8", "3.9", "3.10", "3.11", "3.12", "pypy3"])
 def tests(session):
+    """
+    Run the test suite with a corresponding Python version.
+    """
     session.install("pytest", ROOT)
     env = dict(os.environ, PYTHONWARNDEFAULTENCODING="1")
     session.run("pytest", "--verbosity=3", "--pythonwarnings=error", env=env)
@@ -31,12 +34,18 @@ def tests(session):
 
 @session()
 def audit(session):
+    """
+    Audit dependencies for vulnerabilities.
+    """
     session.install("pip-audit", ROOT)
     session.run("python", "-m", "pip_audit")
 
 
 @session(tags=["build"])
 def build(session):
+    """
+    Build a distribution suitable for PyPI and check its validity.
+    """
     session.install("build", "twine")
     with TemporaryDirectory() as tmpdir:
         session.run("python", "-m", "build", ROOT, "--outdir", tmpdir)
@@ -45,12 +54,18 @@ def build(session):
 
 @session(tags=["style"])
 def style(session):
+    """
+    Check Python code style.
+    """
     session.install("ruff")
     session.run("ruff", "check", ROOT)
 
 
 @session()
 def typing(session):
+    """
+    Check static typing.
+    """
     session.install("mypy", ROOT)
     session.run("python", "-m", "mypy", PACKAGE)
 
@@ -70,12 +85,16 @@ def typing(session):
     ],
 )
 def docs(session, builder):
+    """
+    Build the documentation using a specific Sphinx builder.
+    """
     session.install("-r", DOCS / "requirements.txt")
     with TemporaryDirectory() as tmpdir_str:
         tmpdir = Path(tmpdir_str)
         argv = ["-n", "-T", "-W"]
         if builder != "spelling":
             argv += ["-q"]
+        posargs = session.posargs or [tmpdir / builder]
         session.run(
             "python",
             "-m",
@@ -83,16 +102,36 @@ def docs(session, builder):
             "-b",
             builder,
             DOCS,
-            tmpdir / builder,
             *argv,
+            *posargs,
         )
 
 
 @session(tags=["docs", "style"], name="docs(style)")
 def docs_style(session):
+    """
+    Check the documentation style.
+    """
     session.install(
         "doc8",
         "pygments",
         "pygments-github-lexers",
     )
     session.run("python", "-m", "doc8", "--config", PYPROJECT, DOCS)
+
+
+@session(default=False)
+def requirements(session):
+    """
+    Update the project's pinned requirements. Commit the result.
+    """
+    session.install("pip-tools")
+    for each in [DOCS / "requirements.in"]:
+        session.run(
+            "pip-compile",
+            "--resolver",
+            "backtracking",
+            "--strip-extras",
+            "-U",
+            each.relative_to(ROOT),
+        )
